# ovm-ironic

Document Version: v1.0

#### Table of Contents

- [About](#about)
- [Installation](#installation)
- [Changelog](#changelog)
- [License](#license)

## About

The ovm-ironic is a node discoverer plugin identify which are the nodes in
OpenStack's Ironic that're associated with OneView and inform this to
oneview-monasca.  
You can read more about Ironic [here](https://wiki.openstack.org/wiki/Ironic).

## Installation

The ovm-ironic can be installed using pip, with the following command:

    pip install ovm-ironic

## Changelog

## License

(c) Copyright 2016 Hewlett Packard Enterprise Development LP  
(c) Copyright 2016 Universidade Federal de Campina Grande  

Licensed under the Apache License, Version 2.0 (the "License");  
You may not use this file except in compliance with the License. You may obtain
a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
License for the specific language governing permissions and limitations
under the License.
